@@ -1,4 +1,5 @@
-from MLVisualizationTools import Analytics, Interfaces, Graphs
+from MLVisualizationTools import Analytics, Interfaces, Graphs, Colorizers
+from MLVisualizationTools.backend import fileloader
 import pandas as pd
 import os
 os.environ['TF_CPP_MIN_LOG_LEVEL'] = '2' #stops agressive error message printing
@@ -14,14 +15,14 @@ try:
     import plotly
 except:
     raise ImportError("Dash and plotly are required to run this demo. Install them with the [dash] flag"
-                      "on installation of this library.")
+                      " on installation of this library.")
 
 class App:
     def __init__(self):
         self.app = JupyterDash(__name__, title="Example Dash App")
 
-        self.model = keras.models.load_model('Models/titanicmodel')
-        self.df = pd.read_csv('Datasets/Titanic/train.csv')
+        self.model = keras.models.load_model(fileloader('examples/Models/titanicmodel'))
+        self.df: pd.DataFrame = pd.read_csv(fileloader('examples/Datasets/Titanic/train.csv'))
 
         options = []
         for col in self.df.columns:
@@ -62,10 +63,11 @@ class App:
         self.app.callback(Output("example-graph", "figure"), inputs)(self.updateGraphFromWebsite)
 
     def run(self):
-        self.app.run_server(mode='inline',host="0.0.0.0", port=1005)
+        self.app.run_server(mode='external',host="0.0.0.0", port=1005)
 
     def updateGraph(self):
         data = Interfaces.TensorflowGrid(self.model, self.x, self.y, self.df, ["Survived"])
+        data = Colorizers.Binary(data, highcontrast=True)
         self.fig = Graphs.PlotlyGrid(data, self.x, self.y)
         return self.fig
 
